#!/bin/sh
export PATH='/usr/local/libexec/ccache:/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: lens
version: 4.3.3
id: lens-4.3.3-ee853329c90b5596d8e9d35f2a736b26

license: BSD3
copyright: Copyright (C) 2012-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/lens/
package-url:
synopsis: Lenses, Folds and Traversals
description: This package comes \"Batteries Included\" with many useful lenses for the types
             commonly used from the Haskell Platform, and with tools for automatically
             generating lenses and isomorphisms for user-supplied data types.
             .
             The combinators in @Control.Lens@ provide a highly generic toolbox for composing
             families of getters, folds, isomorphisms, traversals, setters and lenses and their
             indexed variants.
             .
             An overview, with a large number of examples can be found in the <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals README>.
             .
             An introductory video on the style of code used in this library by Simon Peyton Jones is available from <http://skillsmatter.com/podcast/scala/lenses-compositional-data-access-and-manipulation Skills Matter>.
             .
             A video on how to use lenses and how they are constructed is available on <http://youtu.be/cefnmjtAolY?hd=1 youtube>.
             .
             Slides for that second talk can be obtained from <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf comonad.com>.
             .
             More information on the care and feeding of lenses, including a brief tutorial and motivation
             for their types can be found on the <https://github.com/ekmett/lens/wiki lens wiki>.
             .
             A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the <https://github.com/ekmett/lens/blob/master/examples/ example folder>.
             .
             /Lenses, Folds and Traversals/
             .
             With some signatures simplified, the core of the hierarchy of lens-like constructions looks like:
             .
             .
             <<http://i.imgur.com/4fHw3Fd.png>>
             .
             <Hierarchy.png (Local Copy)>
             .
             You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
             use any element of the hierarchy as any type it linked to above it.
             .
             The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).
             .
             For instance:
             .
             * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.
             .
             * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.
             .
             /Minimizing Dependencies/
             .
             If you want to provide lenses and traversals for your own types in your own libraries, then you
             can do so without incurring a dependency on this (or any other) lens package at all.
             .
             /e.g./ for a data type:
             .
             > data Foo a = Foo Int Int a
             .
             You can define lenses such as
             .
             > -- bar :: Lens'\'' (Foo a) Int
             > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
             > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)
             .
             > -- quux :: Lens (Foo a) (Foo b) a b
             > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
             > quux f (Foo a b c) = fmap (Foo a b) (f c)
             .
             without the need to use any type that isn'\''t already defined in the @Prelude@.
             .
             And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':
             .
             > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
             > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
             > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c
             .
             What is provided in this library is a number of stock lenses and traversals for
             common haskell types, a wide array of combinators for working them, and more
             exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).
category: Data, Lenses, Generics
author: Edward A. Kmett
exposed: True
exposed-modules: Codec.Compression.Zlib.Lens Control.Exception.Lens
                 Control.Lens Control.Lens.Action Control.Lens.At
                 Control.Lens.Combinators Control.Lens.Cons Control.Lens.Each
                 Control.Lens.Empty Control.Lens.Equality Control.Lens.Extras
                 Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
                 Control.Lens.Internal Control.Lens.Internal.Action
                 Control.Lens.Internal.Bazaar Control.Lens.Internal.ByteString
                 Control.Lens.Internal.Context Control.Lens.Internal.Deque
                 Control.Lens.Internal.Exception Control.Lens.Internal.Fold
                 Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
                 Control.Lens.Internal.Instances Control.Lens.Internal.Iso
                 Control.Lens.Internal.Level Control.Lens.Internal.Magma
                 Control.Lens.Internal.Prism Control.Lens.Internal.Reflection
                 Control.Lens.Internal.Review Control.Lens.Internal.Setter
                 Control.Lens.Internal.TH Control.Lens.Internal.Zoom
                 Control.Lens.Iso Control.Lens.Lens Control.Lens.Level
                 Control.Lens.Loupe Control.Lens.Operators Control.Lens.Plated
                 Control.Lens.Prism Control.Lens.Reified Control.Lens.Review
                 Control.Lens.Setter Control.Lens.TH Control.Lens.Traversal
                 Control.Lens.Tuple Control.Lens.Type Control.Lens.Wrapped
                 Control.Lens.Zoom Control.Monad.Error.Lens
                 Control.Monad.Primitive.Lens Control.Parallel.Strategies.Lens
                 Control.Seq.Lens Data.Aeson.Lens Data.Array.Lens Data.Bits.Lens
                 Data.ByteString.Lens Data.ByteString.Strict.Lens
                 Data.ByteString.Lazy.Lens Data.Complex.Lens Data.Data.Lens
                 Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
                 Data.List.Split.Lens Data.Map.Lens Data.Sequence.Lens Data.Set.Lens
                 Data.Text.Lens Data.Text.Strict.Lens Data.Text.Lazy.Lens
                 Data.Tree.Lens Data.Typeable.Lens Data.Vector.Lens
                 Data.Vector.Generic.Lens Generics.Deriving.Lens GHC.Generics.Lens
                 System.Exit.Lens System.FilePath.Lens System.IO.Error.Lens
                 Language.Haskell.TH.Lens Numeric.Lens
hidden-modules: Control.Lens.Internal.TupleIxedTH
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.8.3/lens-4.3.3
library-dirs: /usr/local/lib/cabal/ghc-7.8.3/lens-4.3.3
              /usr/local/lib
hs-libraries: HSlens-4.3.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: aeson-0.7.0.6-5ac7c20a63fc09c0ee77dacb9472f023
         array-0.5.0.0-98aa445e59f3eb0c886795ff07406d84
         attoparsec-0.10.4.0-7ee6fb69f8d373108d8583068f8120f7
         base-4.7.0.1-812360bc88c9859b8259f0d90b6e2faa
         bifunctors-4.1.1.1-9cf45024b5e4db4190fabc5a54d6225b
         bytestring-0.10.4.0-2182937da706a7ad10a5093b31e299db
         comonad-4.2.2-e5178a19bf39d5e9a7599ffc3941fb7a
         containers-0.5.5.1-23e2a2b94d6e452c773209f31d8672c5
         contravariant-1.1-94bc574bba045cd398007a0930471e1e
         distributive-0.4.4-767f380201a1333ad86994b760dbd4ee
         exceptions-0.6.1-893932e70ff6297193754955e36a8d92
         filepath-1.3.0.2-1580a61d3226e4be45fe2130dc2881e3
         free-4.9-0b47bed6f293ff32fd1d8c39a1365e00
         ghc-prim-0.3.1.0-954cb57749cf319beafdc89b3415422c
         hashable-1.2.2.0-7cfb61f0c68a03cacd19199a33e9c118
         mtl-2.1.3.1-8bcc0591131896cfc8761a93703d4c61
         parallel-3.2.0.4-e7d84d2578e6412ec995ab7b1bd5ca95
         primitive-0.5.2.1-5c22000e9219643c6a2317b15bf5afd0
         profunctors-4.2.0.1-2fc8c7b88745d0cc27b4fb90cdf2ea7b
         reflection-1.5.1-e781cdf3179931dd11936b0a5ba72d6c
         scientific-0.3.3.0-6a449cd704d3545346905c1931ef316b
         semigroupoids-4.0.4-818778ef061841920ed10f13c6cb0dae
         semigroups-0.15.2-ba0dfd27959c7ba409dc7184903ce406
         split-0.2.2-7c6e2bd13c1e04b85cc7ee759efb1a08
         tagged-0.7.2-28286204801522ac85a55fc42ce891dc
         template-haskell-2.9.0.0-209b23d5bd6678f5bc383f0d56742080
         text-1.1.0.0-ae5f08307fb9d06679d77b9fce515032
         transformers-0.3.0.0-16a97696ae672940f1523b262e566ba5
         transformers-compat-0.3.3.4-858641fe36888a94d2a45d3e79e952ce
         unordered-containers-0.2.4.0-ab8d3f7773b26c54df0958504a88212e
         vector-0.10.9.1-2584ae046ff7f59a3c2a1976714626fe
         void-0.6.1-0cb41d75dcacd001661ded375f400f01
         zlib-0.5.4.1-e192d7a862bf9247587461a5894b2aef
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.8.3/lens-4.3.3/html/lens.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.8.3/lens-4.3.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
